searchNodes=[{"doc":"Documentation for Ortex . Ortex is an Elixir wrapper around ONNX Runtime using Rustler and ORT .","ref":"Ortex.html","title":"Ortex","type":"module"},{"doc":"Load an Ortex.Model from disk. Optionally pass the execution providers as a list of descending priority and graph optimization level 1-3. Any graph optimization level beyond the range of 1-3 will disable graph optimization. Examples iex&gt; Ortex . load ( &quot;./models/tinymodel.onnx&quot; ) iex&gt; Ortex . load ( &quot;./models/tinymodel.onnx&quot; , [ :cuda , :cpu ] ) iex&gt; Ortex . load ( &quot;./models/tinymodel.onnx&quot; , [ :cpu ] , 0 )","ref":"Ortex.html#load/3","title":"Ortex.load/3","type":"function"},{"doc":"Run a forward pass through a model. This takes a model and tuple of Nx.Tensors , optionally transfers them to the Ortex.Backend if they aren't there already, and runs a forward pass through the model. This will return a tuple of Ortex.Backend tensors, it's up to the user to transfer these back to another backend if additional ops are required. If there is only one input you can optionally pass a bare tensor rather than a tuple. Examples iex&gt; model = Ortex . load ( &quot;./models/tinymodel.onnx&quot; ) iex&gt; { % Nx.Tensor { shape : { 1 , 10 } } , ...&gt; % Nx.Tensor { shape : { 1 , 10 } } , ...&gt; % Nx.Tensor { shape : { 1 , 10 } } } = Ortex . run ( ...&gt; model , { ...&gt; Nx . broadcast ( 0 , { 1 , 100 } ) |&gt; Nx . as_type ( :s32 ) , ...&gt; Nx . broadcast ( 0 , { 1 , 100 } ) |&gt; Nx . as_type ( :f32 ) ...&gt; } )","ref":"Ortex.html#run/2","title":"Ortex.run/2","type":"function"},{"doc":"Documentation for Ortex.Backend . This implements the Nx.Backend behaviour for Ortex tensors. Most Nx operations are not implemented for this (although they may be in the future). This is mainly for ergonomic tensor construction and deconstruction from Ortex inputs and outputs. Since this does not implement most Nx operations, it's best NOT to set this as the default backend.","ref":"Ortex.Backend.html","title":"Ortex.Backend","type":"module"},{"doc":"A model for running Ortex inference with. Implements a human-readable representation of a model including the name, dimension, and type of each input and output # Ortex.Model &lt; inputs : [ { &quot;x&quot; , &quot;Int32&quot; , [ nil , 100 ] } , { &quot;y&quot; , &quot;Float32&quot; , [ nil , 100 ] } ] outputs : [ { &quot;9&quot; , &quot;Float32&quot; , [ nil , 10 ] } , { &quot;onnx::Add_7&quot; , &quot;Float32&quot; , [ nil , 10 ] } , { &quot;onnx::Add_8&quot; , &quot;Float32&quot; , [ nil , 10 ] } ] &gt; nil values represent dynamic dimensions","ref":"Ortex.Model.html","title":"Ortex.Model","type":"module"},{"doc":"Ortex.Serving Documentation This is a lightweight wrapper for using Nx.Serving behaviour with Ortex . Using jit and defn functions in this are not supported, it is strictly for serving batches to an Ortex.Model for inference. Examples Inline/serverless workflow To quickly create an Ortex.Serving and run it iex&gt; model = Ortex . load ( &quot;./models/resnet50.onnx&quot; ) iex&gt; serving = Nx.Serving . new ( Ortex.Serving , model ) iex&gt; batch = Nx.Batch . stack ( [ { Nx . broadcast ( 0.0 , { 3 , 224 , 224 } ) } ] ) iex&gt; { result } = Nx.Serving . run ( serving , batch ) iex&gt; result |&gt; Nx . backend_transfer |&gt; Nx . argmax ( axis : 1 ) # Nx.Tensor &lt; s64 [ 1 ] [ 499 ] &gt; Stateful/process workflow An Ortex.Serving can also be started in your Application's supervision tree model = Ortex . load ( &quot;./models/resnet50.onnx&quot; ) children = [ { Nx.Serving , serving : Nx.Serving . new ( Ortex.Serving , model ) , name : MyServing , batch_size : 10 , batch_timeout : 100 } ] opts = [ strategy : :one_for_one , name : OrtexServing.Supervisor ] Supervisor . start_link ( children , opts ) With the application started, batches can now be sent to the Ortex.Serving process iex&gt; Nx.Serving . batched_run ( MyServing , Nx.Batch . stack ( [ { Nx . broadcast ( 0.0 , { 3 , 224 , 224 } ) } ] ) ) ...&gt; { # Nx.Tensor &lt; f32 [ 1 ] [ 1000 ] Ortex.Backend [ [ ... ] ] &gt; }","ref":"Ortex.Serving.html","title":"Ortex.Serving","type":"module"},{"doc":"Ortex is a wrapper around ONNX Runtime (implemented as bindings to ort ). Ortex leverages Nx.Serving to easily deploy ONNX models that run concurrently and distributed in a cluster. Ortex also provides a storage-only tensor implementation for ease of use. ONNX models are a standard machine learning model format that can be exported from most ML libraries like PyTorch and TensorFlow. Ortex allows for easy loading and fast inference of ONNX models using different backends available to ONNX Runtime such as CUDA, TensorRT, Core ML, and ARM Compute Library.","ref":"readme.html","title":"Ortex","type":"extras"},{"doc":"TL;DR: iex&gt; model = Ortex . load ( &quot;./models/resnet50.onnx&quot; ) # Ortex.Model &lt; inputs : [ { &quot;input&quot; , &quot;Float32&quot; , [ nil , 3 , 224 , 224 ] } ] outputs : [ { &quot;output&quot; , &quot;Float32&quot; , [ nil , 1000 ] } ] &gt; iex&gt; { output } = Ortex . run ( model , Nx . broadcast ( 0.0 , { 1 , 3 , 224 , 224 } ) ) iex&gt; output |&gt; Nx . backend_transfer ( ) |&gt; Nx . argmax # Nx.Tensor &lt; s64 499 &gt; Inspecting a model shows the expected inputs, outputs, data types, and shapes. Axes with nil represent a dynamic size. To see more real world examples see the examples folder. Serving Ortex also implements Nx.Serving behaviour. To use it in your application's supervision tree consult the Nx.Serving docs. iex&gt; serving = Nx.Serving . new ( Ortex.Serving , model ) iex&gt; batch = Nx.Batch . stack ( [ { Nx . broadcast ( 0.0 , { 3 , 224 , 224 } ) } ] ) iex&gt; { result } = Nx.Serving . run ( serving , batch ) iex&gt; result |&gt; Nx . backend_transfer ( ) |&gt; Nx . argmax ( axis : 1 ) # Nx.Tensor &lt; s64 [ 1 ] [ 499 ] &gt;","ref":"readme.html#examples","title":"Ortex - Examples","type":"extras"},{"doc":"Ortex can be installed by adding ortex to your list of dependencies in mix.exs : def deps do [ { :ortex , &quot;~&gt; 0.1.4&quot; } ] end You will need Rust for compilation to succeed.","ref":"readme.html#installation","title":"Ortex - Installation","type":"extras"}]